@@ -154,19 +154,22 @@ class GSpreadsheet(object):
             name = row['name']
 
     Parameters:
-      url       : The url to the spreadsheet. Specify this or the key.
-      key       : The key to the spreadsheet. Specify this or the url.
-      worksheet : The name of the worksheet, like 'od6' or 'od7'.
-                  (default: 'default')
-      email     : Your account email address.
-      password  : Your account password
-      readonly  : Whether to allow changes to the `GSpreadsheet`, which can
-                  also change the original. (default: False)
+      url           : The url to the spreadsheet. Specify this or the key.
+      key           : The key to the spreadsheet. Specify this or the url.
+      worksheet     : The name of the worksheet, like 'od6' or 'od7'.
+                      (default: 'default')
+      email         : Your account email address.
+      password      : Your account password
+      readonly      : Whether to allow changes to the `GSpreadsheet`, which can
+                      also change the original. (default: False)
+      deferred_save : Defer saves. You have to explicitly call `.save()` to
+                      write the data back to the spreadsheet.
     """
     # parameters
     key = None
     worksheet = 'default'
     readonly = False
+    deferred_save = False
 
     # state
     client = None  # save auth
@@ -217,6 +220,9 @@ class GSpreadsheet(object):
     def __repr__(self):
         return self.__unicode__()
 
+    def __len__(self):
+        return len(self.feed.entry)
+
     def get_client(self, email=None, password=None, **__):
         """Get the google data client."""
         if self.client is not None:
@@ -273,7 +279,7 @@ class GSpreadsheet(object):
 
     def readrow_as_dict(self):
         for entry in self.feed.entry:
-            row = GDataRow(entry, sheet=self)
+            row = GDataRow(entry, sheet=self, deferred_save=self.deferred_save)
             yield row
 
     # Interactivity methods
@@ -283,4 +289,4 @@ class GSpreadsheet(object):
         # TODO check self.is_authed
         entry = self.client.InsertRow(row_dict, self.key, self.worksheet)
         self.feed.entry.append(entry)
-        return GDataRow(entry, sheet=self)
+        return GDataRow(entry, sheet=self, deferred_save=self.deferred_save)
