@@ -6,7 +6,8 @@ connect to a live spreadsheet whose contents cannot be guaranteed. So take the
 results of these tests with a grain of salt.
 
 """
-from unittest import TestCase, skip
+from unittest import TestCase, skip, skipIf
+import os
 
 from .gspreadsheet import GSpreadsheet, ReadOnlyException
 from .auth import Auth
@@ -17,7 +18,7 @@ TEST_URL = "https://docs.google.com/spreadsheet/ccc?key=%s#gid=0" % KEY
 WRITABLE_TEST_URL = "https://docs.google.com/spreadsheet/ccc?key=%s#gid=1" % KEY
 
 
-class AuthTests(TestCase):
+class BasicAuthTests(TestCase):
     def test_can_connect_and_reuse_client(self):
         sheet = GSpreadsheet(TEST_URL)
         self.assertTrue(sheet)
@@ -26,12 +27,6 @@ class AuthTests(TestCase):
         self.assertTrue(sheet)
         # TODO assert only one auth was made
 
-    @skip("TODO")
-    def test_can_use_client_created_from_auth(self):
-        client = Auth()
-        sheet = GSpreadsheet(TEST_URL, client=client)
-        self.assertTrue(sheet)
-
 
 class Basics(TestCase):
     def test_can_connect_and_iterate_using_url(self):
@@ -41,6 +36,9 @@ class Basics(TestCase):
         for i, row in enumerate(sheet):
             self.assertEqual(row['name'], names[i])
 
+        # test_can_get_length_of_sheet
+        self.assertEqual(len(sheet), i + 1)
+
     def test_can_connect_and_iterate_using_url_no_gid(self):
         sheet = GSpreadsheet(TEST_URL.split("#")[0])
         self.assertEqual(sheet.worksheet, 'default')
@@ -92,11 +90,43 @@ class Basics(TestCase):
         self.assertEqual(type(copy(row)), dict)
         self.assertEqual(type(row.copy()), dict)
 
+
+@skipIf('GOOGLE_ACCOUNT_EMAIL' not in os.environ or
+        'GOOGLE_ACCOUNT_PASSWORD' not in os.environ,
+        'These tests require being logged in')
+class LoggedInTests(TestCase):
+    def test_can_use_client_created_from_auth(self):
+        client = Auth()
+        sheet = GSpreadsheet(TEST_URL, client=client)
+        self.assertTrue(sheet)
+
     def test_can_append_row(self):
         import datetime
         from . import __version__ as VERSION
 
         sheet = GSpreadsheet(WRITABLE_TEST_URL)
-        if sheet.is_authed:
-            sheet.append(dict(date=datetime.datetime.utcnow().isoformat(' ').split('.')[0],
-                value=str(VERSION)))
+
+        self.assertTrue(sheet.is_authed)
+        data_to_write = dict(
+            date=datetime.datetime.utcnow().isoformat(' ').split('.')[0],
+            value=str(VERSION),
+        )
+        sheet.append(data_to_write)
+
+    def test_can_defer_saves_and_delete_rows(self):
+        # yeah this is two tests, but the delete is sorta the tests's teardown
+
+        # setup, write a dummy row
+        sheet = GSpreadsheet(WRITABLE_TEST_URL, deferred_save=True)
+
+        data_to_write = dict(
+            date='DELETEME',
+            value='-1',
+        )
+        row = sheet.append(data_to_write)
+        row['value'] = '-2'
+        self.assertTrue(row._defer_save)
+        self.assertEqual(row._entry.custom['value'].text, '-1')
+        row.save()
+        self.assertEqual(row._entry.custom['value'].text, '-2')
+        row.delete()
